@@ -1,7 +1,7 @@
 package Log::ger::Output::Composite;
 
 our $DATE = '2017-06-25'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use strict;
 use warnings;
@@ -196,7 +196,7 @@ Log::ger::Output::Composite - Composite output
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -204,7 +204,7 @@ version 0.003
      outputs => {
          # single screen output
          Screen => {
-             level => 'info', # set mper-output level. optional.
+             level => 'info', # set per-output level. optional.
              conf => { use_color=>1 },
          },
          # multiple file outputs
@@ -215,7 +215,7 @@ version 0.003
                  # set per-category, per-output level. optional.
                  category_level => {
                      # don't log myapp.security messages to this file
-                     'myapp.security' => 'off',
+                     'MyApp::Security' => 'off',
                  },
              },
              {
@@ -223,15 +223,15 @@ version 0.003
                  level => 'warn',
                  category_level => {
                      # only myapp.security messages go to this file
-                     'myapp.security' => 'warn',
+                     'MyApp::Security' => 'warn',
                  },
              },
          ],
      },
      # set per-category level. optional.
      category_level => {
-        'category1.sub1' => 'info',
-        'category2' => 'debug',
+        'MyApp::SubModule1' => 'info',
+        'MyApp::SubModule2' => 'debug',
         ...
      },
  );
@@ -242,8 +242,8 @@ version 0.003
 =head1 DESCRIPTION
 
 This is a L<Log::ger> output that can multiplex output to several outputs and do
-filtering per-category level, per-output level, or per-output per-category
-level.
+filtering on the basis of per-category level, per-output level, or per-output
+per-category level.
 
 =for Pod::Coverage ^(.+)$
 
@@ -283,24 +283,24 @@ specify minimum and maximum level (e.g. C<<["trace", "info"]>>). If you
 accidentally mix up minimum and maximum, this module will helpfully fix it for
 you.
 
+=item * category_level => hash
+
+Specify per-output per-category level. Hash key is category name, value is level
+(which can be a string/numeric level or a two-element array containing minimum
+and maximum level).
+
 =back
 
 =head2 category_level => hash
 
-=head2
-
-=head1 TODO
-
-Per-category level has not been implemented.
-
-Per-output per-category level has not been implemented.
+Specify per-category level. Hash key is category name, value is level (which can
+be a string/numeric level or a two-element array containing minimum and maximum
+level).
 
 =head1 ENVIRONMENT
 
 =head1 SEE ALSO
 
-Modelled after L<Log::Any::App>.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
